summaryrefslogtreecommitdiffstats
path: root/quanta
diff options
context:
space:
mode:
Diffstat (limited to 'quanta')
-rw-r--r--quanta/components/csseditor/encodingselector.cpp4
-rw-r--r--quanta/components/csseditor/fontfamilychooser.cpp2
-rw-r--r--quanta/dialogs/actionconfigdialog.cpp2
-rw-r--r--quanta/dialogs/dirtydlg.cpp6
-rw-r--r--quanta/dialogs/dirtydlg.h4
-rw-r--r--quanta/dialogs/settings/abbreviation.cpp2
-rw-r--r--quanta/messages/messageoutput.h2
-rw-r--r--quanta/parts/kafka/wkafkapart.cpp6
-rw-r--r--quanta/plugins/quantaplugineditor.cpp4
-rw-r--r--quanta/project/project.cpp2
-rw-r--r--quanta/project/projectnewweb.cpp20
-rw-r--r--quanta/project/projectnewweb.h8
-rw-r--r--quanta/project/projectprivate.cpp2
-rw-r--r--quanta/project/rescanprj.cpp4
-rw-r--r--quanta/quanta_uml.xmi10
-rw-r--r--quanta/src/dtds.cpp10
-rw-r--r--quanta/src/kqapp.cpp6
-rw-r--r--quanta/src/quanta.cpp30
-rw-r--r--quanta/src/quanta.h8
-rw-r--r--quanta/src/quanta_init.cpp28
-rw-r--r--quanta/treeviews/basetreeview.cpp2
-rw-r--r--quanta/treeviews/doctreeview.cpp2
-rw-r--r--quanta/treeviews/scripttreeview.cpp8
-rw-r--r--quanta/utility/myprocess.h2
-rw-r--r--quanta/utility/newstuff.cpp10
-rw-r--r--quanta/utility/tagaction.cpp38
-rw-r--r--quanta/utility/tagaction.h10
-rw-r--r--quanta/utility/toolbartabwidget.cpp4
28 files changed, 118 insertions, 118 deletions
diff --git a/quanta/components/csseditor/encodingselector.cpp b/quanta/components/csseditor/encodingselector.cpp
index f8ba4ac6..ad5b958b 100644
--- a/quanta/components/csseditor/encodingselector.cpp
+++ b/quanta/components/csseditor/encodingselector.cpp
@@ -27,11 +27,11 @@
*/
encodingSelector::encodingSelector(TQWidget *parent, const char* name) : encodingSelectorS(parent,name){
- TQStringList encodings (KGlobal::charsets()->availableEncodingNames());
+ TQStringList encodings (TDEGlobal::charsets()->availableEncodingNames());
int insert = 0;
for (uint i=0; i < encodings.count(); i++) {
bool found = false;
- TQTextCodec *codecForEnc = KGlobal::charsets()->codecForName(encodings[i], found);
+ TQTextCodec *codecForEnc = TDEGlobal::charsets()->codecForName(encodings[i], found);
if (found){
cbEncoding->insertItem (encodings[i]);
diff --git a/quanta/components/csseditor/fontfamilychooser.cpp b/quanta/components/csseditor/fontfamilychooser.cpp
index bd9e59ef..6a390340 100644
--- a/quanta/components/csseditor/fontfamilychooser.cpp
+++ b/quanta/components/csseditor/fontfamilychooser.cpp
@@ -34,7 +34,7 @@
fontFamilyChooser::fontFamilyChooser(TQWidget* parent, const char *name) : fontFamilyChooserS(parent,name){
- TQFont tmpFont( KGlobalSettings::generalFont().family(), 64, TQFont::Black );
+ TQFont tmpFont( TDEGlobalSettings::generalFont().family(), 64, TQFont::Black );
lePreview->setMinimumHeight( lePreview->fontMetrics().lineSpacing() );
lePreview->setAlignment(TQt::AlignCenter);
TQFont font;
diff --git a/quanta/dialogs/actionconfigdialog.cpp b/quanta/dialogs/actionconfigdialog.cpp
index 29cabe4e..7ae6b4a4 100644
--- a/quanta/dialogs/actionconfigdialog.cpp
+++ b/quanta/dialogs/actionconfigdialog.cpp
@@ -152,7 +152,7 @@ ActionConfigDialog::ActionConfigDialog(const TQDict<ToolbarEntry> &toolbarList,
treeMenu->insertItem(i18n("&Remove Toolbar"), this, TQT_SLOT(slotRemoveToolbar()));
treeMenu->insertItem(i18n("&Edit Toolbar"), this, TQT_SLOT(slotEditToolbar()));
- globalShortcuts = KGlobal::config()->entryMap( "Global Shortcuts" );
+ globalShortcuts = TDEGlobal::config()->entryMap( "Global Shortcuts" );
}
ActionConfigDialog::~ActionConfigDialog()
diff --git a/quanta/dialogs/dirtydlg.cpp b/quanta/dialogs/dirtydlg.cpp
index 70d06c86..3664f21f 100644
--- a/quanta/dialogs/dirtydlg.cpp
+++ b/quanta/dialogs/dirtydlg.cpp
@@ -53,10 +53,10 @@ void DirtyDlg::slotOk()
if (m_mainWidget->buttonCompare->isChecked())
{
m_busy = true;
- KProcess *proc = new KProcess();
+ TDEProcess *proc = new TDEProcess();
*proc << "kompare" << m_src.path() << m_dest.path();
proc->start();
- connect(proc, TQT_SIGNAL(processExited(KProcess*)),TQT_SLOT(slotCompareDone(KProcess*)));
+ connect(proc, TQT_SIGNAL(processExited(TDEProcess*)),TQT_SLOT(slotCompareDone(TDEProcess*)));
enableButton(KDialogBase::Ok, false);
enableButton(KDialogBase::Cancel, false);
} else
@@ -70,7 +70,7 @@ void DirtyDlg::slotOk()
}
/** No descriptions */
-void DirtyDlg::slotCompareDone(KProcess* proc)
+void DirtyDlg::slotCompareDone(TDEProcess* proc)
{
delete proc;
diff --git a/quanta/dialogs/dirtydlg.h b/quanta/dialogs/dirtydlg.h
index 194275af..04cf3824 100644
--- a/quanta/dialogs/dirtydlg.h
+++ b/quanta/dialogs/dirtydlg.h
@@ -23,7 +23,7 @@
class DirtyDialog;
class KDialogBase;
-class KProcess;
+class TDEProcess;
class TQCloseEvent;
class DirtyDlg : public KDialogBase {
@@ -38,7 +38,7 @@ protected slots: // Protected slots
/** No descriptions */
void slotOk();
/** No descriptions */
- void slotCompareDone(KProcess*);
+ void slotCompareDone(TDEProcess*);
/** No descriptions */
void slotResult(KIO::Job *);
/** No descriptions */
diff --git a/quanta/dialogs/settings/abbreviation.cpp b/quanta/dialogs/settings/abbreviation.cpp
index 538aaa0b..eb143120 100644
--- a/quanta/dialogs/settings/abbreviation.cpp
+++ b/quanta/dialogs/settings/abbreviation.cpp
@@ -221,7 +221,7 @@ void AbbreviationDlg::saveTemplates()
TQListViewItem *item = templatesList->currentItem();
if (item && m_currentAbbrev)
m_currentAbbrev->abbreviations.insert(item->text(0) + " " + item->text(1), codeEdit->text());
- TQString abbrevFile = KGlobal::dirs()->saveLocation("data") + resourceDir + "abbreviations.xml";
+ TQString abbrevFile = TDEGlobal::dirs()->saveLocation("data") + resourceDir + "abbreviations.xml";
TQString s = "<!DOCTYPE Templates>\n<Templates>\n</Templates>\n";
TQString s2;
TQDomDocument doc;
diff --git a/quanta/messages/messageoutput.h b/quanta/messages/messageoutput.h
index c8ea0f1e..f2a8d894 100644
--- a/quanta/messages/messageoutput.h
+++ b/quanta/messages/messageoutput.h
@@ -20,7 +20,7 @@
#include <tqlistbox.h>
-class KProcess;
+class TDEProcess;
class KPopupMenu;
class MessageItem;
diff --git a/quanta/plugins/quantaplugineditor.cpp b/quanta/plugins/quantaplugineditor.cpp
index e530ee0c..347ae9c6 100644
--- a/quanta/plugins/quantaplugineditor.cpp
+++ b/quanta/plugins/quantaplugineditor.cpp
@@ -168,9 +168,9 @@ void QuantaPluginEditor::refreshPlugins()
TQPixmap statusIcon;
bool isValid = QuantaPlugin::validatePlugin(curPlugin);
if(isValid)
- statusIcon = SmallIcon("ok", KGlobal::instance());
+ statusIcon = SmallIcon("ok", TDEGlobal::instance());
else
- statusIcon = SmallIcon("no", KGlobal::instance());
+ statusIcon = SmallIcon("no", TDEGlobal::instance());
newItem->setPixmap(1, statusIcon);
newItem->setText(2, curPlugin->location());
diff --git a/quanta/project/project.cpp b/quanta/project/project.cpp
index ef737396..aed1942e 100644
--- a/quanta/project/project.cpp
+++ b/quanta/project/project.cpp
@@ -526,7 +526,7 @@ void Project::slotOptions()
optionsPage.dtdCombo->setCurrentItem(pos);
- TQStringList availableEncodingNames(KGlobal::charsets()->availableEncodingNames());
+ TQStringList availableEncodingNames(TDEGlobal::charsets()->availableEncodingNames());
optionsPage.encodingCombo->insertStringList( availableEncodingNames );
TQStringList::ConstIterator iter;
int iIndex = -1;
diff --git a/quanta/project/projectnewweb.cpp b/quanta/project/projectnewweb.cpp
index a087497c..31d3f620 100644
--- a/quanta/project/projectnewweb.cpp
+++ b/quanta/project/projectnewweb.cpp
@@ -105,7 +105,7 @@ void ProjectNewWeb::slotStart()
{
chdir( baseURL.path(1).ascii() );
- proc = new KProcess();
+ proc = new TDEProcess();
proc ->clearArguments();
TQStringList list = TQStringList::split (" ", commandLine->text());
@@ -115,14 +115,14 @@ void ProjectNewWeb::slotStart()
*proc << *it;
}
- connect( proc, TQT_SIGNAL(receivedStdout( KProcess*,char*,int)), this,
- TQT_SLOT( slotGetWgetOutput(KProcess*,char*,int)));
- connect( proc, TQT_SIGNAL(receivedStderr( KProcess*,char*,int)), this,
- TQT_SLOT( slotGetWgetOutput(KProcess*,char*,int)));
- connect( proc, TQT_SIGNAL(processExited( KProcess *)), this,
- TQT_SLOT( slotGetWgetExited(KProcess *)));
+ connect( proc, TQT_SIGNAL(receivedStdout( TDEProcess*,char*,int)), this,
+ TQT_SLOT( slotGetWgetOutput(TDEProcess*,char*,int)));
+ connect( proc, TQT_SIGNAL(receivedStderr( TDEProcess*,char*,int)), this,
+ TQT_SLOT( slotGetWgetOutput(TDEProcess*,char*,int)));
+ connect( proc, TQT_SIGNAL(processExited( TDEProcess *)), this,
+ TQT_SLOT( slotGetWgetExited(TDEProcess *)));
- if (proc->start(KProcess::NotifyOnExit, KProcess::AllOutput))
+ if (proc->start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput))
{
start = true;
button->setText( i18n("Stop") );
@@ -159,7 +159,7 @@ void ProjectNewWeb::slotStart()
}
}
-void ProjectNewWeb::slotGetWgetExited(KProcess*)
+void ProjectNewWeb::slotGetWgetExited(TDEProcess*)
{
KLed2->setState(KLed::Off);
KLed1->setState(KLed::Off);
@@ -169,7 +169,7 @@ void ProjectNewWeb::slotGetWgetExited(KProcess*)
emit enableNextButton((TQWidget *)this->parent(),true);
}
-void ProjectNewWeb::slotGetWgetOutput(KProcess *, char *buffer, int buflen)
+void ProjectNewWeb::slotGetWgetOutput(TDEProcess *, char *buffer, int buflen)
{
TQString output = buffer;
output = output.left( buflen );
diff --git a/quanta/project/projectnewweb.h b/quanta/project/projectnewweb.h
index fa7ff2e0..5c6e2b5e 100644
--- a/quanta/project/projectnewweb.h
+++ b/quanta/project/projectnewweb.h
@@ -29,7 +29,7 @@
*@author Dmitry Poplavsky & Alexander Yakovlev & Eric Laffoon
*/
-class KProcess;
+class TDEProcess;
class KURL;
class ProjectNewWeb : public ProjectNewWebS {
@@ -48,8 +48,8 @@ public slots:
KURL::List files();
- void slotGetWgetExited(KProcess *);
- void slotGetWgetOutput(KProcess *proc, char *buffer, int buflen);
+ void slotGetWgetExited(TDEProcess *);
+ void slotGetWgetOutput(TDEProcess *proc, char *buffer, int buflen);
virtual void resizeEvent( TQResizeEvent * );
@@ -66,7 +66,7 @@ private:
bool start;
- KProcess *proc;
+ TDEProcess *proc;
private slots: // Private slots
/** No descriptions */
diff --git a/quanta/project/projectprivate.cpp b/quanta/project/projectprivate.cpp
index ce3686bf..fd49f0ce 100644
--- a/quanta/project/projectprivate.cpp
+++ b/quanta/project/projectprivate.cpp
@@ -1174,7 +1174,7 @@ void ProjectPrivate::slotNewProject()
if (pos >= 0)
pnf->dtdCombo->setCurrentItem(pos);
- TQStringList availableEncodingNames(KGlobal::charsets()->availableEncodingNames());
+ TQStringList availableEncodingNames(TDEGlobal::charsets()->availableEncodingNames());
pnf->encodingCombo->insertStringList( availableEncodingNames );
TQStringList::ConstIterator iter;
int iIndex = -1;
diff --git a/quanta/project/rescanprj.cpp b/quanta/project/rescanprj.cpp
index bf11498d..daa628a5 100644
--- a/quanta/project/rescanprj.cpp
+++ b/quanta/project/rescanprj.cpp
@@ -88,8 +88,8 @@ void RescanPrj::addEntries(KIO::Job *job,const KIO::UDSEntryList &list)
KURL url = static_cast<KIO::ListJob *>(job)->url();
url.adjustPath(-1);
// avoid creating these TQStrings again and again
- static const TQString& dot = KGlobal::staticQString(".");
- static const TQString& dotdot = KGlobal::staticQString("..");
+ static const TQString& dot = TDEGlobal::staticQString(".");
+ static const TQString& dotdot = TDEGlobal::staticQString("..");
KIO::UDSEntryListConstIterator it = list.begin();
KIO::UDSEntryListConstIterator end = list.end();
diff --git a/quanta/quanta_uml.xmi b/quanta/quanta_uml.xmi
index 96ca78ec..b2c7001b 100644
--- a/quanta/quanta_uml.xmi
+++ b/quanta/quanta_uml.xmi
@@ -823,7 +823,7 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Operation stereotype="" package="" xmi.id="736" type="virtual bool" abstract="0" documentation="" name="unload" static="0" scope="200" />
<UML:Operation stereotype="" package="" xmi.id="737" type="" abstract="0" documentation="" name="~QuantaCmdPlugin" static="0" scope="200" />
<UML:Attribute stereotype="" package="" xmi.id="726" value="" type="bool" abstract="0" documentation="" name="m_firstOutput" static="0" scope="202" />
- <UML:Attribute stereotype="" package="" xmi.id="727" value="" type="KProcess *" abstract="0" documentation="" name="m_process" static="0" scope="202" />
+ <UML:Attribute stereotype="" package="" xmi.id="727" value="" type="TDEProcess *" abstract="0" documentation="" name="m_process" static="0" scope="202" />
</UML:Class>
<UML:Class stereotype="" package="" xmi.id="738" abstract="0" documentation="" name="PluginEditorItem" static="0" scope="200" >
<UML:Operation stereotype="" package="" xmi.id="739" type="" abstract="0" documentation="" name="PluginEditorItem" static="0" scope="200" >
@@ -1606,7 +1606,7 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Operation stereotype="" package="" xmi.id="1377" type="" abstract="0" documentation="" name="~ProjectNewWeb" static="0" scope="200" />
<UML:Attribute stereotype="" package="" xmi.id="1368" value="" type="KURL" abstract="0" documentation="" name="baseURL" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1369" value="" type=TQSTRINGLIST_OBJECT_NAME_STRING abstract="0" documentation="" name="filesList" static="0" scope="201" />
- <UML:Attribute stereotype="" package="" xmi.id="1370" value="" type="KProcess *" abstract="0" documentation="" name="proc" static="0" scope="201" />
+ <UML:Attribute stereotype="" package="" xmi.id="1370" value="" type="TDEProcess *" abstract="0" documentation="" name="proc" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1371" value="" type="bool" abstract="0" documentation="" name="start" static="0" scope="201" />
</UML:Class>
<UML:Class stereotype="" package="" xmi.id="1378" abstract="0" documentation="" name="ProjectNewGeneral" static="0" scope="200" >
@@ -1741,12 +1741,12 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Operation stereotype="" package="" xmi.id="1493" type="virtual void" abstract="0" documentation="" name="insertTag" static="0" scope="202" />
<UML:Operation stereotype="" package="" xmi.id="1494" type="virtual void" abstract="0" documentation="" name="scriptDone" static="0" scope="202" />
<UML:Operation stereotype="" package="" xmi.id="1495" type="virtual void" abstract="0" documentation="" name="slotGetScriptError" static="0" scope="202" >
- <UML:Parameter stereotype="" package="" xmi.id="1496" value="" type="KProcess *" abstract="0" documentation="" name="" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="1496" value="" type="TDEProcess *" abstract="0" documentation="" name="" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1497" value="" type="char *" abstract="0" documentation="" name="buffer" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1498" value="" type="int" abstract="0" documentation="" name="buflen" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="1499" type="virtual void" abstract="0" documentation="" name="slotGetScriptOutput" static="0" scope="202" >
- <UML:Parameter stereotype="" package="" xmi.id="1500" value="" type="KProcess *" abstract="0" documentation="" name="" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="1500" value="" type="TDEProcess *" abstract="0" documentation="" name="" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1501" value="" type="char *" abstract="0" documentation="" name="buffer" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1502" value="" type="int" abstract="0" documentation="" name="buflen" static="0" scope="200" />
</UML:Operation>
@@ -1754,7 +1754,7 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Attribute stereotype="" package="" xmi.id="1480" value="" type="bool" abstract="0" documentation="" name="firstError" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1481" value="" type="bool" abstract="0" documentation="" name="firstOutput" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1482" value="" type="QuantaView *" abstract="0" documentation="" name="m_view" static="0" scope="201" />
- <UML:Attribute stereotype="" package="" xmi.id="1483" value="" type="KProcess *" abstract="0" documentation="" name="proc" static="0" scope="201" />
+ <UML:Attribute stereotype="" package="" xmi.id="1483" value="" type="TDEProcess *" abstract="0" documentation="" name="proc" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1484" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="scriptErrorDest" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1485" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="scriptOutputDest" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1486" value="" type="QDomElement" abstract="0" documentation="" name="tag" static="0" scope="201" />
diff --git a/quanta/src/dtds.cpp b/quanta/src/dtds.cpp
index c378bd05..97ec6ec0 100644
--- a/quanta/src/dtds.cpp
+++ b/quanta/src/dtds.cpp
@@ -67,8 +67,8 @@ DTDs::DTDs(TQObject *parent)
m_dict->setAutoDelete(true);
m_doc = new TQDomDocument();
- TQString localKDEdir = KGlobal::instance()->dirs()->localtdedir();
- TQStringList tagsResourceDirs = KGlobal::instance()->dirs()->findDirs("appdata", "dtep");
+ TQString localKDEdir = TDEGlobal::instance()->dirs()->localtdedir();
+ TQStringList tagsResourceDirs = TDEGlobal::instance()->dirs()->findDirs("appdata", "dtep");
TQStringList tagsDirs;
TQStringList::ConstIterator end = tagsResourceDirs.constEnd();
for ( TQStringList::ConstIterator it = tagsResourceDirs.constBegin(); it != end; ++it )
@@ -904,7 +904,7 @@ void DTDs::slotLoadDTD()
KURL url = KFileDialog::getOpenURL("", i18n("*.dtd|DTD Definitions"), 0L);
if (!url.isEmpty())
{
- DTDParser dtdParser(url, KGlobal::dirs()->saveLocation("data") + resourceDir + "dtep");
+ DTDParser dtdParser(url, TDEGlobal::dirs()->saveLocation("data") + resourceDir + "dtep");
if (dtdParser.parse())
{
TQString dirName = dtdParser.dirName();
@@ -962,7 +962,7 @@ void DTDs::slotLoadDTEP(const TQString &_dirName, bool askForAutoload)
KURL src;
src.setPath(dirName);
KURL target;
- TQString destDir = KGlobal::dirs()->saveLocation("data") + resourceDir + "dtep/";
+ TQString destDir = TDEGlobal::dirs()->saveLocation("data") + resourceDir + "dtep/";
target.setPath(destDir + src.fileName());
KIO::copy( src, target, false); //don't care about the result
}
@@ -993,7 +993,7 @@ void DTDs::slotLoadEntities()
if (dlg.exec())
{
DTDStruct * dtd = m_dict->find(getDTDNameFromNickName(entitiesWidget.targetDTEPCombo->currentText()));
- DTDParser dtdParser(KURL::fromPathOrURL(entitiesWidget.sourceDTDRequester->url()), KGlobal::dirs()->saveLocation("data") + resourceDir + "dtep");
+ DTDParser dtdParser(KURL::fromPathOrURL(entitiesWidget.sourceDTDRequester->url()), TDEGlobal::dirs()->saveLocation("data") + resourceDir + "dtep");
TQString dtdDir = TQFileInfo(dtd->fileName).dirPath();
if (dtdParser.parse(dtdDir, true))
{
diff --git a/quanta/src/kqapp.cpp b/quanta/src/kqapp.cpp
index 39053e86..3b306f0f 100644
--- a/quanta/src/kqapp.cpp
+++ b/quanta/src/kqapp.cpp
@@ -47,7 +47,7 @@ KSplash::KSplash()
TQPixmap pm( UserIcon(SPLASH_PICTURE) );
setBackgroundPixmap(pm);
- TQRect desk = KGlobalSettings::splashScreenDesktopGeometry();
+ TQRect desk = TDEGlobalSettings::splashScreenDesktopGeometry();
setGeometry( desk.center().x()-225, desk.center().y()-150, 450, 300 );
setLineWidth(0);
show();
@@ -65,7 +65,7 @@ KQApplication::KQApplication()
args = TDECmdLineArgs::parsedArgs();
splash = 0L;
- KGlobal::dirs()->addPrefix(PREFIX);
+ TDEGlobal::dirs()->addPrefix(PREFIX);
dcopClient()->registerAs("quanta", true);
//FIXME: Do not hide the problem, but really fix the session restoration.
@@ -121,7 +121,7 @@ void KQApplication::slotSplashTimeout()
KQUniqueApplication::KQUniqueApplication()
: KUniqueApplication()
{
- KGlobal::dirs()->addPrefix(PREFIX);
+ TDEGlobal::dirs()->addPrefix(PREFIX);
dcopClient()->registerAs("quanta", false);
}
diff --git a/quanta/src/quanta.cpp b/quanta/src/quanta.cpp
index 82c81283..434bff2f 100644
--- a/quanta/src/quanta.cpp
+++ b/quanta/src/quanta.cpp
@@ -218,7 +218,7 @@ QuantaApp::QuantaApp(int mdiMode) : DCOPObject("WindowManagerIf"), KMdiMainFrm(
connect(idleTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotIdleTimerExpired()));
m_idleTimerEnabled = true;
- qConfig.globalDataDir = KGlobal::dirs()->findResourceDir("data",resourceDir + "toolbar/quantalogo.png");
+ qConfig.globalDataDir = TDEGlobal::dirs()->findResourceDir("data",resourceDir + "toolbar/quantalogo.png");
if (qConfig.globalDataDir.isEmpty())
{
quantaStarted = false;
@@ -316,7 +316,7 @@ QuantaApp::~QuantaApp()
}
m_toolbarList.clear();
- TQStringList tmpDirs = KGlobal::dirs()->resourceDirs("tmp");
+ TQStringList tmpDirs = TDEGlobal::dirs()->resourceDirs("tmp");
tmpDir = tmpDirs[0];
for (uint i = 0; i < tmpDirs.count(); i++)
{
@@ -511,7 +511,7 @@ bool QuantaApp::slotFileSaveAs(QuantaView *viewToSave)
"all/allfiles text/html text/xml application/x-php text/plain", this, i18n("Save File"));
KURL saveUrl = data.URLs[0];
bool found;
- TQString encoding = KGlobal::charsets()->codecForName(data.encoding, found)->name();
+ TQString encoding = TDEGlobal::charsets()->codecForName(data.encoding, found)->name();
KTextEditor::EncodingInterface* encodingIf = dynamic_cast<KTextEditor::EncodingInterface*>(w->doc());
if (encodingIf && encodingIf->encoding() != encoding)
encodingIf->setEncoding(encoding);
@@ -1042,7 +1042,7 @@ void QuantaApp::slotConfigureToolbars(const TQString& defaultToolbar)
TQDomNodeList nodeList;
ToolbarEntry *p_toolbar = 0L;
- saveMainWindowSettings(KGlobal::config(), autoSaveGroup());
+ saveMainWindowSettings(TDEGlobal::config(), autoSaveGroup());
KEditToolbar *dlg;
if (!defaultToolbar.isEmpty())
dlg = new KEditToolbar(defaultToolbar, factory(), this);
@@ -1129,7 +1129,7 @@ void QuantaApp::slotOptionsConfigureToolbars()
void QuantaApp::slotNewToolbarConfig()
{
- applyMainWindowSettings(KGlobal::config(), autoSaveGroup());
+ applyMainWindowSettings(TDEGlobal::config(), autoSaveGroup());
ToolbarTabWidget::ref()->setCurrentPage(currentPageIndex);
}
@@ -1191,7 +1191,7 @@ void QuantaApp::slotOptions()
fileMasks->sbAutoSave->setValue(m_config->readNumEntry("Autosave interval"));
//else default value 15
- TQStringList availableEncodingNames(KGlobal::charsets()->availableEncodingNames());
+ TQStringList availableEncodingNames(TDEGlobal::charsets()->availableEncodingNames());
fileMasks->encodingCombo->insertStringList( availableEncodingNames );
TQStringList::ConstIterator iter;
int iIndex = -1;
@@ -1800,7 +1800,7 @@ TQWidget* QuantaApp::createContainer( TQWidget *parent, int index, const TQDomEl
//kdDebug(24000) << "tb->iconSize() " << tb->iconSize() << endl;
if (toolbarTab->iconText() == KToolBar::IconTextBottom)
{
- tb->setGeometry(0,0, toolbarTab->width(), tb->iconSize() + TQFontMetrics(KGlobalSettings::toolBarFont()).height() + 10);
+ tb->setGeometry(0,0, toolbarTab->width(), tb->iconSize() + TQFontMetrics(TDEGlobalSettings::toolBarFont()).height() + 10);
toolbarTab->setFixedHeight(toolbarTab->tabHeight() + tb->height() + 3);
} else
{
@@ -2884,7 +2884,7 @@ bool QuantaApp::removeToolbars()
}
}
- TQFile f(KGlobal::instance()->dirs()->saveLocation("data")+resourceDir + "actions.rc" );
+ TQFile f(TDEGlobal::instance()->dirs()->saveLocation("data")+resourceDir + "actions.rc" );
if (f.open( IO_ReadWrite | IO_Truncate ))
{
if (!m_actions->firstChild().firstChild().isNull())
@@ -3935,7 +3935,7 @@ void QuantaApp::slotAutosaveTimer()
}
/** Get script output */
-void QuantaApp::slotGetScriptOutput(KProcess* ,char* buf,int buflen)
+void QuantaApp::slotGetScriptOutput(TDEProcess* ,char* buf,int buflen)
{
TQCString tmp( buf, buflen + 1 );
m_scriptOutput = TQString();
@@ -3943,14 +3943,14 @@ void QuantaApp::slotGetScriptOutput(KProcess* ,char* buf,int buflen)
}
/** Get script error*/
-void QuantaApp::slotGetScriptError(KProcess* ,char* buf,int buflen)
+void QuantaApp::slotGetScriptError(TDEProcess* ,char* buf,int buflen)
{
//TODO: Implement some error handling?
Q_UNUSED(buf);
Q_UNUSED(buflen);
}
/** Notify when process exits*/
-void QuantaApp::slotProcessExited(KProcess* process)
+void QuantaApp::slotProcessExited(TDEProcess* process)
{
slotProcessTimeout();
delete process;
@@ -4767,10 +4767,10 @@ void QuantaApp::slotViewInKFM()
}
if ( !w->isUntitled() )
{
- KProcess *show = new KProcess(TQT_TQOBJECT(this));
+ TDEProcess *show = new TDEProcess(TQT_TQOBJECT(this));
KURL url = Project::ref()->urlWithPrefix(w->url());
*show << "kfmclient" << "newTab" << url.url();
- show->start( KProcess::DontCare );
+ show->start( TDEProcess::DontCare );
}
}
@@ -4801,7 +4801,7 @@ void QuantaApp::slotViewInLynx()
}
if ( !w->isUntitled() )
{
- KProcess *show = new KProcess(TQT_TQOBJECT(this));
+ TDEProcess *show = new TDEProcess(TQT_TQOBJECT(this));
KURL url = Project::ref()->urlWithPrefix(w->url());
*show << "konsole"
<< "--nohist"
@@ -4811,7 +4811,7 @@ void QuantaApp::slotViewInLynx()
<< "-e"
<< "lynx"
<< url.url();
- show->start( KProcess::DontCare );
+ show->start( TDEProcess::DontCare );
}
}
diff --git a/quanta/src/quanta.h b/quanta/src/quanta.h
index e7714aea..c701d25b 100644
--- a/quanta/src/quanta.h
+++ b/quanta/src/quanta.h
@@ -73,7 +73,7 @@ class KHTMLView;
class KAction;
class KToggleAction;
-class KProcess;
+class TDEProcess;
class KSelectAction;
class KRecentFilesAction;
class KToolBarPoupAction;
@@ -468,11 +468,11 @@ protected slots:
void slotIdleTimerExpired();
void slotShowNoFramesPreview();
/** Get script output */
- void slotGetScriptOutput(KProcess*, char*, int);
+ void slotGetScriptOutput(TDEProcess*, char*, int);
/** Get script error */
- void slotGetScriptError(KProcess*, char*, int);
+ void slotGetScriptError(TDEProcess*, char*, int);
/** Notify when process exits */
- void slotProcessExited(KProcess*);
+ void slotProcessExited(TDEProcess*);
/** External app execution timeout handling */
void slotProcessTimeout();
diff --git a/quanta/treeviews/basetreeview.cpp b/quanta/treeviews/basetreeview.cpp
index 9ff82da5..278505a2 100644
--- a/quanta/treeviews/basetreeview.cpp
+++ b/quanta/treeviews/basetreeview.cpp
@@ -618,7 +618,7 @@ void BaseTreeView::insertOpenWithMenu(KPopupMenu *menu, int position)
TQDictIterator<QuantaPlugin> it2(plugins);
for(;it2.current();++it2)
{
- int id = m_openWithMenu->insertItem(KGlobal::iconLoader()->loadIconSet(it2.current()->icon(),KIcon::Small), it2.current()->name());
+ int id = m_openWithMenu->insertItem(TDEGlobal::iconLoader()->loadIconSet(it2.current()->icon(),KIcon::Small), it2.current()->name());
m_pluginIds[id] = it2.current();
}
connect(m_openWithMenu, TQT_SIGNAL(activated(int)), TQT_SLOT(slotOpenWithActivated(int)));
diff --git a/quanta/treeviews/doctreeview.cpp b/quanta/treeviews/doctreeview.cpp
index dbd7c11a..39d8ba5b 100644
--- a/quanta/treeviews/doctreeview.cpp
+++ b/quanta/treeviews/doctreeview.cpp
@@ -80,7 +80,7 @@ void DocTreeView::slotRefreshTree()
delete *it;
}
m_folderList.clear();
- TQStringList docDirs = KGlobal::instance()->dirs()->findDirs("appdata", "doc");
+ TQStringList docDirs = TDEGlobal::instance()->dirs()->findDirs("appdata", "doc");
for ( TQStringList::Iterator it = docDirs.begin(); it != docDirs.end(); ++it )
{
diff --git a/quanta/treeviews/scripttreeview.cpp b/quanta/treeviews/scripttreeview.cpp
index eb64dd0b..6819e1ca 100644
--- a/quanta/treeviews/scripttreeview.cpp
+++ b/quanta/treeviews/scripttreeview.cpp
@@ -172,9 +172,9 @@ void ScriptTreeView::slotEditScript()
emit openFile(urlToOpen);
else
{
- KProcess *proc = new KProcess();
+ TDEProcess *proc = new TDEProcess();
*proc << editApp << urlToOpen.path();
- proc->start(KProcess::DontCare);
+ proc->start(TDEProcess::DontCare);
}
}
}
@@ -195,11 +195,11 @@ void ScriptTreeView::slotRun()
}
else
{
- KProcess *proc = new KProcess();
+ TDEProcess *proc = new TDEProcess();
TQStringList argsList = TQStringList::split(' ', execApp);
*proc << argsList;
*proc << urlToOpen.path();
- proc->start(KProcess::DontCare);
+ proc->start(TDEProcess::DontCare);
}
}
}
diff --git a/quanta/utility/myprocess.h b/quanta/utility/myprocess.h
index 0b530af2..a80a199c 100644
--- a/quanta/utility/myprocess.h
+++ b/quanta/utility/myprocess.h
@@ -18,7 +18,7 @@
#include <kprocess.h>
-class MyProcess:public KProcess
+class MyProcess:public TDEProcess
{
Q_OBJECT
diff --git a/quanta/utility/newstuff.cpp b/quanta/utility/newstuff.cpp
index bc3a052f..96c18bbe 100644
--- a/quanta/utility/newstuff.cpp
+++ b/quanta/utility/newstuff.cpp
@@ -36,7 +36,7 @@ void QNewDTEPStuff::installResource()
if (tar.open(IO_ReadOnly))
{
const KArchiveDirectory *directory = tar.directory();
- TQString dtepDir =KGlobal::dirs()->saveLocation("data") + resourceDir + "dtep/";
+ TQString dtepDir =TDEGlobal::dirs()->saveLocation("data") + resourceDir + "dtep/";
TQString dtdName = (*directory->entries().at(0));
if (dtdName.isEmpty())
{
@@ -62,7 +62,7 @@ QNewToolbarStuff::QNewToolbarStuff(const TQString &type, TQWidget *parentWidget
void QNewToolbarStuff::installResource()
{
- KURL destURL = KURL::fromPathOrURL(KGlobal::dirs()->saveLocation("data") + resourceDir + "toolbars/" + TQFileInfo(m_tarName).fileName());
+ KURL destURL = KURL::fromPathOrURL(TDEGlobal::dirs()->saveLocation("data") + resourceDir + "toolbars/" + TQFileInfo(m_tarName).fileName());
bool ok = true;
if (QuantaCommon::checkOverwrite(destURL, parentWidget()))
{
@@ -89,7 +89,7 @@ QNewTemplateStuff::QNewTemplateStuff(const TQString &type, TQWidget *parentWidg
void QNewTemplateStuff::installResource()
{
- KURL destURL = KURL::fromPathOrURL(KGlobal::dirs()->saveLocation("data") + resourceDir + "templates/" + TQFileInfo(m_tarName).fileName());
+ KURL destURL = KURL::fromPathOrURL(TDEGlobal::dirs()->saveLocation("data") + resourceDir + "templates/" + TQFileInfo(m_tarName).fileName());
bool ok = true;
if (QuantaCommon::checkOverwrite(destURL, parentWidget()))
{
@@ -114,7 +114,7 @@ void QNewScriptStuff::installResource()
if (tar.open(IO_ReadOnly))
{
const KArchiveDirectory *directory = tar.directory();
- TQString scriptsDir =KGlobal::dirs()->saveLocation("data") + resourceDir + "scripts/";
+ TQString scriptsDir =TDEGlobal::dirs()->saveLocation("data") + resourceDir + "scripts/";
directory->copyTo(scriptsDir, true);
tar.close();
} else
@@ -131,7 +131,7 @@ void QNewDocStuff::installResource()
if (tar.open(IO_ReadOnly))
{
const KArchiveDirectory *directory = tar.directory();
- TQString docDir =KGlobal::dirs()->saveLocation("data") + resourceDir + "doc/";
+ TQString docDir =TDEGlobal::dirs()->saveLocation("data") + resourceDir + "doc/";
directory->copyTo(docDir, true);
tar.close();
} else
diff --git a/quanta/utility/tagaction.cpp b/quanta/utility/tagaction.cpp
index 57830da9..ae27c526 100644
--- a/quanta/utility/tagaction.cpp
+++ b/quanta/utility/tagaction.cpp
@@ -62,14 +62,14 @@
#include "viewmanager.h"
-MyProcess::MyProcess():KProcess()
+MyProcess::MyProcess():TDEProcess()
{
}
int MyProcess::commSetupDoneC()
{
::setpgid(pid_, 0);
- return KProcess::commSetupDoneC();
+ return TDEProcess::commSetupDoneC();
}
TagAction::TagAction( TQDomElement *element, KMainWindow *parentMainWindow, bool toggle)
@@ -434,12 +434,12 @@ bool TagAction::slotActionActivated(KAction::ActivationReason reason, TQt::Butto
firstOutput = true;
firstError = true;
- connect( proc, TQT_SIGNAL(receivedStdout( KProcess*,char*,int)), this,
- TQT_SLOT( slotGetScriptOutput(KProcess*,char*,int)));
- connect( proc, TQT_SIGNAL(receivedStderr( KProcess*,char*,int)), this,
- TQT_SLOT( slotGetScriptError(KProcess*,char*,int)));
- connect( proc, TQT_SIGNAL(processExited( KProcess*)), this,
- TQT_SLOT( slotProcessExited(KProcess*)));
+ connect( proc, TQT_SIGNAL(receivedStdout( TDEProcess*,char*,int)), this,
+ TQT_SLOT( slotGetScriptOutput(TDEProcess*,char*,int)));
+ connect( proc, TQT_SIGNAL(receivedStderr( TDEProcess*,char*,int)), this,
+ TQT_SLOT( slotGetScriptError(TDEProcess*,char*,int)));
+ connect( proc, TQT_SIGNAL(processExited( TDEProcess*)), this,
+ TQT_SLOT( slotProcessExited(TDEProcess*)));
@@ -458,7 +458,7 @@ bool TagAction::slotActionActivated(KAction::ActivationReason reason, TQt::Butto
*proc << m_inputFileName;
}
- if (proc->start(KProcess::NotifyOnExit, KProcess::All))
+ if (proc->start(TDEProcess::NotifyOnExit, TDEProcess::All))
{
emit clearMessages();
emit showMessage(i18n("The \"%1\" script started.\n").arg(actionText()), false);
@@ -688,12 +688,12 @@ bool TagAction::slotActionActivated()
firstOutput = true;
firstError = true;
- connect( proc, TQT_SIGNAL(receivedStdout( KProcess*,char*,int)), this,
- TQT_SLOT( slotGetScriptOutput(KProcess*,char*,int)));
- connect( proc, TQT_SIGNAL(receivedStderr( KProcess*,char*,int)), this,
- TQT_SLOT( slotGetScriptError(KProcess*,char*,int)));
- connect( proc, TQT_SIGNAL(processExited( KProcess*)), this,
- TQT_SLOT( slotProcessExited(KProcess*)));
+ connect( proc, TQT_SIGNAL(receivedStdout( TDEProcess*,char*,int)), this,
+ TQT_SLOT( slotGetScriptOutput(TDEProcess*,char*,int)));
+ connect( proc, TQT_SIGNAL(receivedStderr( TDEProcess*,char*,int)), this,
+ TQT_SLOT( slotGetScriptError(TDEProcess*,char*,int)));
+ connect( proc, TQT_SIGNAL(processExited( TDEProcess*)), this,
+ TQT_SLOT( slotProcessExited(TDEProcess*)));
@@ -712,7 +712,7 @@ bool TagAction::slotActionActivated()
*proc << m_inputFileName;
}
- if (proc->start(KProcess::NotifyOnExit, KProcess::All))
+ if (proc->start(TDEProcess::NotifyOnExit, TDEProcess::All))
{
emit clearMessages();
emit showMessage(i18n("The \"%1\" script started.\n").arg(actionText()), false);
@@ -740,7 +740,7 @@ bool TagAction::slotActionActivated()
return true;
}
-void TagAction::slotGetScriptOutput( KProcess *, char *buffer, int buflen )
+void TagAction::slotGetScriptOutput( TDEProcess *, char *buffer, int buflen )
{
TQCString tmp( buffer, buflen + 1 );
TQString text( TQString::fromLocal8Bit(tmp) );
@@ -801,7 +801,7 @@ void TagAction::slotGetScriptOutput( KProcess *, char *buffer, int buflen )
firstOutput = false;
}
-void TagAction::slotGetScriptError( KProcess *, char *buffer, int buflen )
+void TagAction::slotGetScriptError( TDEProcess *, char *buffer, int buflen )
{
Document *w = ViewManager::ref()->activeDocument();
TQCString tmp( buffer, buflen + 1 );
@@ -963,7 +963,7 @@ void TagAction::slotActivated()
*/
}
-void TagAction::slotProcessExited(KProcess *process)
+void TagAction::slotProcessExited(TDEProcess *process)
{
if (loopStarted)
{
diff --git a/quanta/utility/tagaction.h b/quanta/utility/tagaction.h
index 62a751d2..3a58f603 100644
--- a/quanta/utility/tagaction.h
+++ b/quanta/utility/tagaction.h
@@ -27,7 +27,7 @@
class KMainWindow;
class QuantaView;
-class KProcess;
+class TDEProcess;
class TQDomElement;
class TQFile;
class TQTimer;
@@ -97,11 +97,11 @@ public slots:
virtual bool slotActionActivated(KAction::ActivationReason reason, TQt::ButtonState state);
protected slots:
- virtual void slotGetScriptOutput( KProcess *, char *buffer, int buflen );
- virtual void slotGetScriptError( KProcess *, char *buffer, int buflen );
+ virtual void slotGetScriptOutput( TDEProcess *, char *buffer, int buflen );
+ virtual void slotGetScriptError( TDEProcess *, char *buffer, int buflen );
virtual void scriptDone();
void slotTimeout();
- void slotProcessExited(KProcess *);
+ void slotProcessExited(TDEProcess *);
virtual bool slotActionActivated();
private:
@@ -115,7 +115,7 @@ private:
NodeSelection& selection, NodeModifsSet* modifs) const;
private:
- KProcess *proc;
+ TDEProcess *proc;
bool firstError;
bool firstOutput;
bool m_modified;
diff --git a/quanta/utility/toolbartabwidget.cpp b/quanta/utility/toolbartabwidget.cpp
index 0104c745..c594c46b 100644
--- a/quanta/utility/toolbartabwidget.cpp
+++ b/quanta/utility/toolbartabwidget.cpp
@@ -217,7 +217,7 @@ int ToolbarTabWidget::tabHeight() const
int height = tabBar()->height();
if (height < 2)
{
- height = TQFontMetrics(KGlobalSettings::generalFont()).height() + 12;
+ height = TQFontMetrics(TDEGlobalSettings::generalFont()).height() + 12;
}
return height;
}
@@ -263,7 +263,7 @@ void QuantaToolBar::slotIconTextChanged(int id)
{
ToolbarTabWidget *toolbarTab = ToolbarTabWidget::ref();
int width = toolbarTab->width();
- int bigHeight = iconSize() + TQFontMetrics(KGlobalSettings::toolBarFont()).height() + 10;
+ int bigHeight = iconSize() + TQFontMetrics(TDEGlobalSettings::toolBarFont()).height() + 10;
int normalHeight = iconSize() + 10;
for (int i = 0; i < toolbarTab->count(); i++)
{
diff --git a/quanta/parts/kafka/wkafkapart.cpp b/quanta/parts/kafka/wkafkapart.cpp
index 58f04b75..8880dd27 100644
--- a/quanta/parts/kafka/wkafkapart.cpp
+++ b/quanta/parts/kafka/wkafkapart.cpp
@@ -879,7 +879,7 @@ TQString KafkaDocument::getDecodedChar(const TQString &encodedChar)
if(it == encodedChars.end())
{
//try this
- return KGlobal::charsets()->resolveEntities(encodedChar);;
+ return TDEGlobal::charsets()->resolveEntities(encodedChar);;
}
return it.data();
}
@@ -940,7 +940,7 @@ TQString KafkaDocument::getDecodedText(const TQString &a_encodedText, bool trans
encodedText << "\"" << endl;
#endif
return encodedText;
//return KGlobal::charsets()->resolveEntities(encodedText); =>nice but not sufficient
}
TQString KafkaDocument::getEncodedChar(const TQString &decodedChar, const TQString &previousDecodedChar)
@@ -1099,7 +1099,7 @@ TQString KafkaDocument::generateCodeFromNode(Node *node, int bLine, int bCol, in
if(encodeText)
text = getEncodedText(node->tag->tagStr(), bLine, bCol, eLine, eCol,
!hasPreParent);
- /** Can't use KGlobal::charsets()->toEntity() :
+ /** Can't use TDEGlobal::charsets()->toEntity() :
* It translate all chars into entities! */
else if(!hasPreParent)
text = node->tag->tagStr().replace(TQRegExp("\\s+"), " ");
@@ -940,7 +940,7 @@ TQString KafkaDocument::getDecodedText(const TQString &a_encodedText, bool trans
#endif
return encodedText;
- //return KGlobal::charsets()->resolveEntities(encodedText); =>nice but not sufficient
+ //return TDEGlobal::charsets()->resolveEntities(encodedText); =>nice but not sufficient
}
TQString KafkaDocument::getEncodedChar(const TQString &decodedChar, const TQString &previousDecodedChar)
diff --git a/quanta/src/quanta_init.cpp b/quanta/src/quanta_init.cpp
index 42765a21..73d6c858 100644
--- a/quanta/src/quanta_init.cpp
+++ b/quanta/src/quanta_init.cpp
@@ -133,7 +133,7 @@ void QuantaInit::initQuanta()
m_config = quantaApp->m_config;
parser = new Parser();
- TQStringList tmpDirs = KGlobal::dirs()->resourceDirs("tmp");
+ TQStringList tmpDirs = TDEGlobal::dirs()->resourceDirs("tmp");
TQDir dir;
tmpDir = tmpDirs[0];
for (uint i = 0; i < tmpDirs.count(); i++)
@@ -276,7 +276,7 @@ void QuantaInit::initQuanta()
//get the PID of this running instance
qConfig.quantaPID = TQString::number(int(getpid()), 10);
- qConfig.backupDirPath = KGlobal::instance()->dirs()->saveLocation("data", resourceDir + "backups/");
+ qConfig.backupDirPath = TDEGlobal::instance()->dirs()->saveLocation("data", resourceDir + "backups/");
m_quanta->autosaveTimer = new TQTimer(m_quanta);
connect(m_quanta->autosaveTimer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(m_quanta), TQT_SLOT(slotAutosaveTimer()));
@@ -1267,19 +1267,19 @@ void QuantaInit::recoverCrashed(TQStringList& recoveredFileNameList)
void QuantaInit::execCommandPS(const TQString& cmd)
{
//We create a KProcess that executes the "ps" *nix command to get the PIDs of the
//other instances of quanta actually running
- KProcess *execCommand = new KProcess();
+ TDEProcess *execCommand = new TDEProcess();
*(execCommand) << TQStringList::split(" ",cmd);
- connect(execCommand, TQT_SIGNAL(receivedStdout(KProcess*,char*,int)),
- TQT_TQOBJECT(m_quanta), TQT_SLOT(slotGetScriptOutput(KProcess*,char*,int)));
- connect(execCommand, TQT_SIGNAL(receivedStderr(KProcess*,char*,int)),
- TQT_TQOBJECT(m_quanta), TQT_SLOT(slotGetScriptError(KProcess*,char*,int)));
- connect(execCommand, TQT_SIGNAL(processExited(KProcess*)),
- TQT_TQOBJECT(m_quanta), TQT_SLOT(slotProcessExited(KProcess*)));
+ connect(execCommand, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+ TQT_TQOBJECT(m_quanta), TQT_SLOT(slotGetScriptOutput(TDEProcess*,char*,int)));
+ connect(execCommand, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+ TQT_TQOBJECT(m_quanta), TQT_SLOT(slotGetScriptError(TDEProcess*,char*,int)));
+ connect(execCommand, TQT_SIGNAL(processExited(TDEProcess*)),
+ TQT_TQOBJECT(m_quanta), TQT_SLOT(slotProcessExited(TDEProcess*)));
- if (!execCommand->start(KProcess::NotifyOnExit,KProcess::All))
+ if (!execCommand->start(TDEProcess::NotifyOnExit,TDEProcess::All))
{
KMessageBox::error(m_quanta, i18n("Failed to query for running Quanta instances."));
}
@@ -1516,7 +1516,7 @@ void QuantaInit::readAbbreviations()
bool mainAbbrevFileFound = false;
TQStringList mainFileList;
mainFileList << qConfig.globalDataDir + resourceDir + "abbreviations.xml";
- mainFileList << KGlobal::dirs()->saveLocation("data") + resourceDir + "abbreviations.xml";
+ mainFileList << TDEGlobal::dirs()->saveLocation("data") + resourceDir + "abbreviations.xml";
for (uint i = 0; i < mainFileList.count(); i++)
{
if (!TQFile::exists(mainFileList[i]))
@@ -1565,7 +1565,7 @@ void QuantaInit::readAbbreviations()
dirName = dirURL.path(1);
TQString abbrevFile = dirName;
TQString tmpStr = dirName;
- TQStringList resourceDirs = KGlobal::dirs()->resourceDirs("data");
+ TQStringList resourceDirs = TDEGlobal::dirs()->resourceDirs("data");
bool dirFound = false;
for (uint i = 0; i < resourceDirs.count(); i++)
{
@@ -1578,7 +1578,7 @@ void QuantaInit::readAbbreviations()
}
if (dirFound)
{
- abbrevFile = KGlobal::dirs()->saveLocation("data", tmpStr) +"/";
+ abbrevFile = TDEGlobal::dirs()->saveLocation("data", tmpStr) +"/";
}
abbrevFile.append("abbreviations");
if (!TQFile::exists(abbrevFile))
@@ -1267,19 +1267,19 @@ void QuantaInit::recoverCrashed(TQStringList& recoveredFileNameList)
void QuantaInit::execCommandPS(const TQString& cmd)
{
- //We create a KProcess that executes the "ps" *nix command to get the PIDs of the
+ //We create a TDEProcess that executes the "ps" *nix command to get the PIDs of the
//other instances of quanta actually running